#include <iostream>
using namespace std;

const int MAX = 100;
const char WHITE = '.';
const char BLACK = 'X';
const char UNKNOWN = '?';
const char EMPTY = 'e';

struct rowcol
{
	int n;
	int vals[MAX/2+1];
	int lens[MAX/2+1];
	bool done;
} rows[MAX], cols[MAX];

char grid[MAX][MAX];
bool rdiff[MAX] = {0};
bool cdiff[MAX] = {0};
char combined[MAX];

void printGrid(int rows, int cols)
{
	for(int i=0; i<rows; i++) {
		for(int j=0; j<cols; j++)
			cout << grid[i][j];
		cout << endl;
	}
}

bool okToPlaceRowVal(int r, int start, int len, int ncols)
{
//cout << "ok: checking r, start = " << r << ',' << start << endl;
	if (start > 1 && grid[r][start-1] == BLACK)
		return false;
	for(int i=start; i<start+len; i++) {
		if (grid[r][i] == WHITE)
			return false;
	}
//cout << "  last check = " << !(start+len <ncols  && grid[r][start+len] == BLACK) << endl;
	return !(start+len <ncols  && grid[r][start+len] == BLACK);
}

void doRow(int r, int ncols, int iv, int start, char layout[])
{
	if (iv == rows[r].n) {
		for(int i=0; i<ncols; i++) {
			if (grid[r][i] == BLACK && layout[i] != BLACK)
				return;
			if (grid[r][i] == WHITE && layout[i] != WHITE)
				return;
		}
//cout << ' ';
//for(int i=0; i<ncols; i++)
//cout << layout[i];
//cout << endl;
		for(int i=0; i<ncols; i++) {
			if (combined[i] == UNKNOWN)
				continue;
			else if (combined[i] == EMPTY)
				combined[i] = layout[i];
			else if (combined[i] != layout[i])
				combined[i] = UNKNOWN;
		}
	}
	else {
		for(int i = start; i <= ncols-rows[r].lens[iv]; i++)
			if (okToPlaceRowVal(r, i, rows[r].vals[iv], ncols)) {
				for(int j=0; j<rows[r].vals[iv]; j++)
					layout[i+j] = BLACK;
				doRow(r, ncols, iv+1, i+rows[r].vals[iv]+1, layout);
				for(int j=0; j<rows[r].vals[iv]; j++)
					layout[i+j] = WHITE;
			}
	}
}

bool doRow(int r, int ncols, bool cdiff[])
{
//cout << "doRow: r = " << r << endl;
	char layout[MAX];
	bool changes = false;
	for(int i=0; i<ncols; i++) {
		layout[i] = WHITE;
		combined[i] = EMPTY;
	}
	doRow(r, ncols, 0, 0, layout);
	for(int i=0; i<ncols; i++) {
		if ((combined[i] == WHITE || combined[i] == BLACK) && grid[r][i] != combined[i]) {
			grid[r][i] = combined[i];
			cdiff[i] = true;
			changes = true;
		}
	}
	return changes;
}

bool rowDone(int r, int ncols)
{
	for(int i=0; i<ncols; i++)
		if (grid[r][i] == UNKNOWN)
			return false;
	return true;
}
	
bool doRows(int n, int m, bool rdiff[], bool cdiff[], bool firstTime)
{
	bool result = false;
	for(int i=0; i<n; i++)
		if (firstTime || (rdiff[i] && !rowDone(i, m)))
			result |= doRow(i, m, cdiff);
	return result;
}

bool okToPlaceCol(int c, int start, int len, int nrows)
{
//cout << "ok: checking r, start = " << r << ',' << start << endl;
	if (start > 1 && grid[start-1][c] == BLACK)
		return false;
	for(int i=start; i<start+len; i++) {
		if (grid[i][c] == WHITE)
			return false;
	}
//cout << "  last check = " << !(start+len <nrows  && grid[r][start+len] == BLACK) << endl;
	return !(start+len <nrows  && grid[start+len][c] == BLACK);
}

void doCol(int c, int nrows, int iv, int start, char layout[])
{
	if (iv == cols[c].n) {
		for(int i=0; i<nrows; i++) {
			if (grid[i][c] == BLACK && layout[i] != BLACK)
				return;
			if (grid[i][c] == WHITE && layout[i] != WHITE)
				return;
		}
//cout << ' ';
//for(int i=0; i<nrows; i++)
//cout << layout[i];
//cout << endl;
		for(int i=0; i<nrows; i++) {
			if (combined[i] == UNKNOWN)
				continue;
			else if (combined[i] == EMPTY)
				combined[i] = layout[i];
			else if (combined[i] != layout[i])
				combined[i] = UNKNOWN;
		}
	}
	else {
		for(int i = start; i <= nrows-cols[c].lens[iv]; i++)
			if (okToPlaceCol(c, i, cols[c].vals[iv], nrows)) {
				for(int j=0; j<cols[c].vals[iv]; j++)
					layout[i+j] = BLACK;
				doCol(c, nrows, iv+1, i+cols[c].vals[iv]+1, layout);
				for(int j=0; j<cols[c].vals[iv]; j++)
					layout[i+j] = WHITE;
			}
	}
}

bool doCol(int c, int nrows, bool rdiff[])
{
//cout << "doCol: c = " << c << endl;
	char layout[MAX];
	bool changes = false;
	for(int i=0; i<nrows; i++) {
		layout[i] = WHITE;
		combined[i] = EMPTY;
	}
	doCol(c, nrows, 0, 0, layout);
	for(int i=0; i<nrows; i++) {
		if ((combined[i] == WHITE || combined[i] == BLACK) && grid[i][c] != combined[i]) {
			grid[i][c] = combined[i];
			rdiff[i] = true;
			changes = true;
		}
	}
	return changes;
}

bool colDone(int c, int nrows)
{
	for(int i=0; i<nrows; i++)
		if (grid[i][c] == UNKNOWN)
			return false;
	return true;
}
	
bool doCols(int n, int m, bool cdiff[], bool rdiff[], bool firstTime)
{
	bool result = false;
	for(int i=0; i<n; i++)
		if (firstTime || (cdiff[i] && !colDone(i, m)))
			result |= doCol(i, m, rdiff);
	return result;
}

int main()
{
	int n, m;
	cin >> n >> m;
	for(int i=0; i<n; i++)
		for(int j=0; j<m; j++)
			grid[i][j] = UNKNOWN;
	for(int i=0; i<n; i++) {
		cin >> rows[i].n;
		rows[i].lens[0] = 0;
		for(int j=0; j<rows[i].n; j++) {
			cin >> rows[i].vals[j];
			rows[i].lens[0] += rows[i].vals[j];
		}
		rows[i].lens[0] += rows[i].n-1;			// add in spaces
		for(int j=1; j<rows[i].n; j++)
			rows[i].lens[j] = rows[i].lens[j-1] - rows[i].vals[j-1] - 1;
		rows[i].done = false;
	}
	for(int i=0; i<m; i++) {
		cin >> cols[i].n;
		cols[i].lens[0] = 0;
		for(int j=0; j<cols[i].n; j++) {
			cin >> cols[i].vals[j];
			cols[i].lens[0] += cols[i].vals[j];
		}
		cols[i].lens[0] += cols[i].n-1;			// add in spaces
		for(int j=1; j<cols[i].n; j++)
			cols[i].lens[j] = cols[i].lens[j-1] - cols[i].vals[j-1] - 1;
		cols[i].done = false;
	}
	bool changesMade = false;
											// first pass on rows
	for(int i=0; i<n; i++) {
		if (rows[i].n == 0) {
			for(int j=0; j<m; j++)
				grid[i][j] = WHITE;
			rows[i].done = true;
			changesMade = true;
		}
		else {
			int sum = rows[i].lens[0];
			if (sum == m) {
				for(int j=0; j<rows[i].vals[0]; j++)
					grid[i][j] = BLACK;
				int index = rows[i].vals[0];
				for(int k=1; k<rows[i].n; k++) {
					grid[i][index] = WHITE;
					for(int j=index+1; j<index+1+rows[i].vals[k]; j++)
						grid[i][j] = BLACK;
					index += 1+rows[i].vals[k];
				}
				rows[i].done = true;
				changesMade = true;
			}
			else {
				int diff = m - sum;
				int index = 0;
				for(int k=0; k<rows[i].n; k++) {
					if (rows[i].vals[k] > diff) {
						for(int j=index+diff; j < index+rows[i].vals[k]; j++)
							grid[i][j] = BLACK;
						changesMade = true;
					}
					index += 1+rows[i].vals[k];
				}
			}
		}
	}
											// first pass on cols
	for(int j=0; j<m; j++) {
		if (cols[j].n == 0) {
			for(int i=0; i<n; i++)
				grid[i][j] = WHITE;
			cols[j].done = true;
			changesMade = true;
		}
		else {
			int sum = cols[j].lens[0];
			if (sum == n) {
				for(int i=0; i<cols[j].vals[0]; i++)
					grid[i][j] = BLACK;
				int index = cols[j].vals[0];
				for(int k=1; k<cols[j].n; k++) {
					grid[index][j] = WHITE;
					for(int i=index+1; i<index+1+cols[j].vals[k]; i++)
						grid[i][j] = BLACK;
					index += 1+cols[j].vals[k];
				}
				cols[j].done = true;
				changesMade = true;
			}
			else {
				int diff = n - sum;
				int index = 0;
				for(int k=0; k<cols[j].n; k++) {
					if (cols[j].vals[k] > diff) {
						for(int i=index+diff; i < index+cols[j].vals[k]; i++) {
							grid[i][j] = BLACK;
						}
						changesMade = true;
					}
					index += 1+cols[j].vals[k];
				}
			}
		}
	}
//printGrid(n, m); cout << endl;
	bool first = true;
	while (changesMade) {
		for(int i=0; i<m; i++)
			cdiff[i] = false;
		changesMade = doRows(n, m, rdiff, cdiff, first);
//printGrid(n, m); cout << endl;
		for(int i=0; i<m; i++)
			rdiff[i] = false;
		changesMade |= doCols(m, n, cdiff, rdiff, first);
		first = false;
//printGrid(n, m); cout << endl;
	}
	printGrid(n, m);
}

